Module: ActiveJob::Callbacks
- Extended by:
- ActiveSupport::Callbacks, ActiveSupport::Concern
- Includes:
- ActiveSupport::Callbacks
- Included in:
- Base
- Defined in:
- lib/active_job/callbacks.rb
Overview
Active Job Callbacks
Active Job provides hooks during the life cycle of a job. Callbacks allow you to trigger logic during this cycle. Available callbacks are:
- before_enqueue
- around_enqueue
- after_enqueue
- before_perform
- around_perform
- after_perform
Defined Under Namespace
Modules: ClassMethods