Module: ActiveJob::Enqueuing
Defined Under Namespace
Modules: ClassMethods
Instance Method Summary collapse
-
#enqueue(options = {}) ⇒ Object
Enqueues the job to be performed by the queue adapter.
Instance Method Details
#enqueue(options = {}) ⇒ Object
Enqueues the job to be performed by the queue adapter.
Options
- :wait - Enqueues the job with the specified delay
- :wait_until - Enqueues the job at the time specified
- :queue - Enqueues the job on the specified queue
- :priority - Enqueues the job with the specified priority
Examples
my_job_instance.enqueue
my_job_instance.enqueue wait: 5.minutes
my_job_instance.enqueue queue: :important
my_job_instance.enqueue wait_until: Date.tomorrow.midnight
my_job_instance.enqueue priority: 10
82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/active_job/enqueuing.rb', line 82 def enqueue( = {}) set() self.successfully_enqueued = false self.enqueue_error = nil raw_enqueue if successfully_enqueued? self else false end end |