Module: ActiveJob::Exceptions
Overview
Provides behavior for retrying and discarding jobs on exceptions.
Defined Under Namespace
Modules: ClassMethods
Instance Method Summary collapse
-
#retry_job(options = {}) ⇒ Object
Reschedules the job to be re-executed.
Instance Method Details
#retry_job(options = {}) ⇒ Object
Reschedules the job to be re-executed. This is useful in combination with rescue_from. When you rescue an exception from your job you can ask Active Job to retry performing your job.
Options
- :wait - Enqueues the job with the specified delay in seconds
- :wait_until - Enqueues the job at the time specified
- :queue - Enqueues the job on the specified queue
- :priority - Enqueues the job with the specified priority
Examples
class SiteScraperJob < ActiveJob::Base rescue_from(ErrorLoadingSite) do retry_job queue: :low_priority end
def perform(*args)
# raise ErrorLoadingSite if cannot scrape
end
end
158 159 160 161 162 163 164 165 |
# File 'lib/active_job/exceptions.rb', line 158 def retry_job( = {}) instrument :enqueue_retry, .slice(:error, :wait) do scheduled_at, queue_name, priority = self.scheduled_at, self.queue_name, self.priority enqueue ensure self.scheduled_at, self.queue_name, self.priority = scheduled_at, queue_name, priority end end |